<!--- DO NOT EDIT THIS FILE. Generated by README.py-->
# Basic

## Fields

```
./fields.py
```
Output directory `out_fields`:
* [`train.log`](https://cselab.github.io/odil/examples/out_fields/train.log)
* [`train.csv`](https://cselab.github.io/odil/examples/out_fields/train.csv)
* [`grid_00000.png`](https://cselab.github.io/odil/examples/out_fields/grid_00000.png)  
  <img src="https://cselab.github.io/odil/examples/out_fields/grid_00000.png" height=200>
* [`grid_00001.png`](https://cselab.github.io/odil/examples/out_fields/grid_00001.png)  
  <img src="https://cselab.github.io/odil/examples/out_fields/grid_00001.png" height=200>
